#
# spec file for package jujutsu
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define binary_name jj

Name:           jujutsu
Version:        0.11.0
Release:        1.1
Summary:	Git-compatible DVCS that is both simple and powerful
License:        MIT
URL:            https://github.com/martinvonz/jj
Source0:        jj-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo >= 1.70
BuildRequires:  cargo-packaging
BuildRequires:  openssl-devel
BuildRequires:  zstd

%description
Jujutsu is a Git-compatible DVCS. It combines features from Git (data model, speed), Mercurial (anonymous branching, simple CLI free from "the index", revsets, powerful history-rewriting), and Pijul/Darcs (first-class conflicts), with features not found in most of them (working-copy-as-a-commit, undo functionality, automatic rebase, safe replication via rsync, Dropbox, or distributed file system).

The command-line tool is called jj for now because it's easy to type and easy to replace (rare in English). The project is called "Jujutsu" because it matches "jj".

Jujutsu is relatively young, with lots of work to still be done. If you have any questions, or want to talk about future plans, please join us on Discord Discord or start a GitHub Discussion; the developers monitor both channels.

Important
Jujutsu is an experimental version control system. While Git compatibility is stable, and most developers use it daily for all their needs, there may still be work-in-progress features, suboptimal UX, and workflow gaps that make it unusable for your particular use.

%prep
%autosetup -p 1 -a 1 -n jj-%{version}
mkdir -p .cargo
rm -vf .cargo/config.toml
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
ls -lh %{_builddir}/
install -m 0755 %{_builddir}/%{binary_name}-%{version}/target/release/%{binary_name} %{buildroot}%{_bindir}/%{binary_name}

%check
%{cargo_test}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{binary_name}

%changelog
* Wed Nov  1 2023 kastl@b1-systems.de
- Update to version 0.11.0:
  * Breaking changes
  - Conflicts are now stored in a different way. Commits written
    by a new jj binary will not be read correctly by older jj
    binaries. The new model solves some performance problems with
    the old model. For example, jj log should be noticeably
    faster on large repos. You may need to create a new clone to
    see the full speedup.
  - The remote_branches() revset now includes branches exported
    to the Git repository (so called Git-tracking branches.) Use
    remote_branches(remote=exact:"origin") to query branches of
    certain remote.
  - Status messages are now printed to stderr.
  - jj config set now interprets the value as TOML also if it's a
    valid TOML array or table. For example, jj config set --user
    'aliases.n' '["new"]'
  - Remote branches now have tracking or non-tracking flags. The
    git.auto-local-branch setting is applied only to newly
    fetched remote branches. Existing remote branches are
    migrated as follows:
  - If local branch exists, the corresponding remote branches
    are considered tracking branches.
  - Otherwise, the remote branches are non-tracking branches.
  - If the deduced tracking flags are wrong, use jj branch
    track/untrack commands to fix them up.
  - See automatic local branch creation for details.
  - Non-tracking remote branches aren't listed by default. Use jj
    branch list --all to show all local and remote branches.
  - It's not allowed to push branches if non-tracking remote
    branches of the same name exist.
  - Pushing deleted/moved branches no longer abandons the local
    commits referenced by the remote branches.
  - jj git fetch --branch now requires glob: prefix to expand *
    in branch name.
  * New features
  - jj's stable release can now be installed with cargo binstall
    jj-cli.
  - jj workspace add now takes a --revision argument.
  - jj workspace forget can now forget multiple workspaces at
    once.
  - branches()/remote_branches()/author()/committer()/description()
    revsets now support glob matching.
  - jj branch delete/forget/list, and jj git push --branch now
    support string pattern syntax. The --glob option is
    deprecated in favor of glob: pattern.
  - The branches/tags/git_refs/git_head template keywords now
    return a list of RefNames. They were previously pre-formatted
    strings.
  - The new template keywords local_branches/remote_branches are
    added to show only local/remote branches.
  - jj workspace add now preserves all parents of the old
    working-copy commit instead of just the first one.
  - jj rebase -r gained the ability to rebase a revision A onto a
    descendant of A.
  * Fixed bugs
  - Updating the working copy to a commit where a file that's
    currently ignored in the working copy no longer leads to a
    crash (#976).
  - Conflicts in executable files can now be resolved just like
    conflicts in non-executable files (#1279).
  - jj new --insert-before and --insert-after now respect
    immutable revisions (#2468).
* Mon Oct  9 2023 Johannes Kastl <kastl@b1-systems.de>
- new package jujutsu: A Git-compatible DVCS that is both simple
  and powerful
